> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Heartrate 3 Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.
On EasyAVR V7 remember to switch sw6.3, sw6.4, sw5.7 and sw5.8 to on, for TWI comm.
###Example on AVR
```
 #include <stdint.h>
 #include "heartrate_3.h"

sbit RST at PORTA6_bit;
sbit RST_DIR at DDA6_bit;

void system_setup( void );
void interrupt_setup( void );


void system_setup( void )
{
       //Local Declarations
     char            text[20] = { 0 };
     dynamic_modes_t dynamic_modes;
     uint8_t         address = 0x58;

     RST_DIR = 1;
        //Set up dynamic modes for Heart Rate 3 Initialization
     dynamic_modes.transmit = trans_en;
     dynamic_modes.curr_range = led_norm;
     dynamic_modes.adc_power = adc_off;
     dynamic_modes.clk_mode = osc_mode;
     dynamic_modes.tia_power = tia_off;
     dynamic_modes.rest_of_adc = rest_of_adc_off;
     dynamic_modes.afe_rx_mode = afe_rx_normal;
     dynamic_modes.afe_mode = afe_normal;

       //UART Initialize
     UART1_Init( 9600 );
     UART1_Write_Text( "UART is Initialized\r\n" );
     
       // TWI
     TWI_Init( 100000 );
     Delay_ms(500);
     UART1_Write_Text( "TWI Initialized\r\n" );

       //Toggle Reset pin
     RST = 0;
     Delay_us(25);
     RST = 1;
     Delay_ms(200);

       //Heart Rate 3 Initialize
     hr3_init( address, &dynamic_modes );
     UART1_Write_Text( "HR3 Initialized\r\n" );
     
     initStatHRM();      // Initializes values to 0
     Delay_ms(100);

     interrupt_setup();
}

void adc_rdy_isr() iv IVT_ADDR_INT0 ics ICS_AUTO
{
     statHRMAlgo( hr3_get_led1_amb1_val() );
}

void interrupt_setup( void )
{
     MCUCR |= ( 3 << ISC00 );              // Rising edge
     GICR  |= ( 1 << INT0 );               // Enable Interrupts on INT0
     SREG  |= ( 1 << 7 );                  // Enable Globabl Interrupts
}

```

```
void main()
{    //Local Declarations
     uint16_t   rate     = 0;
     uint32_t led1 = 0;
     char  uart_text[20] = {0};

     system_setup();     // GPIO / HeartRate 3 / UART / I2C Setups
     Delay_ms(200);

       while(1)
       {
          led1 = 0;
          rate = hr3_get_heartrate();                                   // Gets current Heartrate

          LongWordToStr( rate, uart_text );
          UART1_Write_Text( uart_text );
          UART1_Write_Text( "\r\n" );
       }
}

```

